summaryrefslogtreecommitdiffstatshomepage
path: root/src/emu/ui/selsoft.cpp
diff options
context:
space:
mode:
author Jordi Mallach <jordi@mallach.net>2016-03-31 23:38:58 +0200
committer Jordi Mallach <jordi@mallach.net>2016-04-01 02:28:16 +0200
commit94ad873787e87c3bf6feb1581baebf60caed76f9 (patch)
treead110d3829bfc4738784b7b88036678097cc5266 /src/emu/ui/selsoft.cpp
parent80890952a78a71c2e4a29b0178285774d2ed4e8c (diff)
Typo fix: softwares → software
Software is uncountable. At most, we can use "pieces of software" or so.
Diffstat (limited to 'src/emu/ui/selsoft.cpp')
-rw-r--r--src/emu/ui/selsoft.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/emu/ui/selsoft.cpp b/src/emu/ui/selsoft.cpp
index 0022297f6c8..1c85ccf5fde 100644
--- a/src/emu/ui/selsoft.cpp
+++ b/src/emu/ui/selsoft.cpp
@@ -4,7 +4,7 @@
ui/selsoft.cpp
- UI softwares menu.
+ UI software menu.
***************************************************************************/
@@ -517,7 +517,7 @@ void ui_menu_select_software::populate()
}
//-------------------------------------------------
// build a list of softwares
//-------------------------------------------------
void ui_menu_select_software::build_software_list()
@@ -678,7 +678,7 @@ void ui_menu_select_software::custom_render(void *selectedref, float top, float
// determine the text for the header
int vis_item = (m_search[0] != 0) ? visible_items : (m_has_empty_start ? visible_items - 1 : visible_items);
- tempbuf[0] = string_format(_("%1$s %2$s ( %3$d / %4$d softwares )"), emulator_info::get_appname(), bare_build_version, vis_item, m_swinfo.size() - 1);
+ tempbuf[0] = string_format(_("%1$s %2$s ( %3$d / %4$d software )"), emulator_info::get_appname(), bare_build_version, vis_item, m_swinfo.size() - 1);
tempbuf[1] = string_format(_("Driver: \"%1$s\" software list "), m_driver->description);
if (sw_filters::actual == UI_SW_REGION && m_filter.region.ui.size() != 0)
@@ -517,7 +517,7 @@ void ui_menu_select_software::populate()
}
//-------------------------------------------------
-// build a list of softwares
+// build a list of software
//-------------------------------------------------
void ui_menu_select_software::build_software_list()